@@ -12,8 +12,8 @@ chartrim = <<"CHRTRM"
 
 Subroutine CHAR_TRIM(string,tfstring,len)
     Use Iso_C_Binding
-    Character(1,C_char),Intent(In) :: string(*)
-    Character*(*)  :: tfstring
+    Character(1,C_char),Intent(In)  :: string(*)
+    Character(1,C_char),Intent(Out) :: tfstring(*)
     Integer(c_int) i,len
 
     Do i=1,len
@@ -208,9 +208,9 @@ puts chartrim
 
         CHAR_LEN.length.times do |i|
 
-          if fcname[0][-4..-1]=="get_"
-            if fcname[0][-5..-1]=="cget_"
-              if VALS[CHAR_VALS[i]]=="B"
+          if fcname[0][-4..-1]=="get_" || fcname[0][-4..-1]=="set_" then
+            if fcname[0][-5..-1]=="cget_" then
+              if VALS[CHAR_VALS[i]]=="B" then
                 print("  CALL CHAR_TRIM(" +VALS[CHAR_VALS[i]]+"A,"+VALS[CHAR_VALS[i]]+","+VALS[CHAR_LEN[i]].to_s+")\n")
               end
             else
